@@ -21,6 +21,7 @@
  */
 
 #include <libgda/gda-config.h>
+#include <libgnomedb/gnome-db-config.h>
 #include <libgnomedb/gnome-db-data-source-selector.h>
 #include <libgnomedb/gnome-db-dsn-config-druid.h>
 #include <libgnomedb/gnome-db-i18n.h>
@@ -251,6 +252,7 @@ gnome_db_login_construct (GnomeDbLogin *login, const gchar *dsn)
 
 	label = gnome_db_new_label_widget (_("Data Source:"));
         gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
+	gtk_label_set_selectable (GTK_LABEL (label), FALSE);
         gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1, GTK_FILL, GTK_FILL, 0, 0);
 	login->priv->dsn_entry = gnome_db_data_source_selector_new (dsn);
@@ -267,6 +269,7 @@ gnome_db_login_construct (GnomeDbLogin *login, const gchar *dsn)
 
 	label = gnome_db_new_label_widget (_("Username:"));
         gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
+	gtk_label_set_selectable (GTK_LABEL (label), FALSE);
         gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2, GTK_FILL, GTK_FILL, 0, 0);
 	login->priv->username_entry = gnome_db_new_entry_widget (0, TRUE);
@@ -275,6 +278,7 @@ gnome_db_login_construct (GnomeDbLogin *login, const gchar *dsn)
 
 	label = gnome_db_new_label_widget (_("Password:"));
         gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
+	gtk_label_set_selectable (GTK_LABEL (label), FALSE);
         gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 2, 3, GTK_FILL, GTK_FILL, 0, 0);
 	login->priv->password_entry = gnome_db_new_entry_widget (0, TRUE);
